@@ -14,6 +14,7 @@ from django.template.loader import render_to_string
 from django.contrib.humanize.templatetags.humanize import naturaltime
 
 # Time
+import time
 from datetime import datetime
 from django.utils import timezone
 
@@ -236,7 +237,7 @@ class Command(CalAccessCommand):
 
         # Stream the download
         chunk_size = 1024
-        resp = requests.get(self.url, stream=True, headers=headers)
+        resp = requests.get(self.url, stream=True, headers=headers, verify=False)
         logger.debug(
             'Response status {0.status_code} ({0.reason}) from GET request.'.format(resp)
         )
@@ -275,21 +276,37 @@ class Command(CalAccessCommand):
                 fp.write(chunk)
                 fp.flush()
 
-    def archive(self):
+    def archive(self, suffix=None):
         """
         Save a copy of the download zip file and each file inside.
         """
         if self.verbosity:
             self.log(" Archiving {}".format(os.path.basename(self.zip_path)))
-        # Remove previous zip file
-        self.version.download_zip_archive.delete()
         # Store the actual download zip file size
         self.version.download_zip_size = os.path.getsize(self.zip_path)
         # Open up the zipped file so we can wrap it in the Django File obj
-        zipped_file = open(self.zip_path, 'rb')
-        # Save the zip on the raw data version
-        self.version.download_zip_archive.save(
-            self.url.split('/')[-1],
-            File(zipped_file)
-        )
-        zipped_file.close()
+        release_datetime = self.version.release_datetime
+        identifier = "ccdc-raw-data-{dt:%Y-%m-%d_%H-%M-%S}".format(dt=release_datetime)
+        if suffix:
+            identifier += suffix
+        with open(self.zip_path, 'rb') as f:
+            # Save the zip on the raw data version
+            try:
+                self.version.download_zip_archive.save(
+                    identifier,
+                    File(f),
+                    metadata=dict(
+                        title=f"CAL-ACCESS raw data ({self.version.release_datetime})"
+                    )
+                )
+            except FileExistsError:
+                self.version.download_zip_archive.delete()
+                time.sleep(60)
+                self.version.download_zip_archive.save(
+                    identifier,
+                    File(f),
+                    metadata=dict(
+                        title=f"CAL-ACCESS raw data ({self.version.release_datetime})"
+                    )
+                )
+        return identifier
